=========
Analytics
=========

The ``oscar.analytics`` module provides a few simple models for gathering analytics data
on products and users.  It listens for signals from other apps, and creates/updates simple
models which aggregate this data.

Such data is useful for auto-merchandising, calculating product scores for search and 
for personalised marketing for customers.   
